{************************************************************}
{*                                                          *}
{*     ThkColorPicker v1.0                                  *}
{*     Copyright (c) 2004 Hristo Kostov (Runner).           *}
{*     All rights reserved.                                 *}
{*                                                          *}
{*     E-mail:     runner@bulgaria.com                      *}
{*     Home page:  http://runner.hit.bg                     *}
{*                                                          *}
{************************************************************}

unit hkColorPicker;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, ExtCtrls;

type
  ThkAboutInfo = type string;

  ThkColorPicker = class(TComponent)
  private
    FAbout: ThkAboutInfo;
    FDC: HDC;
    FTimer: TTimer;
    FOnTimer: TNotifyEvent;
    function GetColor: TColor;
    function GetEnabled: Boolean;
    function GetInterval: Cardinal;
    procedure SetAbout(Value: ThkAboutInfo);
    procedure SetEnabled(Value: Boolean);
    procedure SetInterval(Value: Cardinal);
    procedure SetOnTimer(Value: TNotifyEvent);
    procedure TimerHandler(Sender: TObject);
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    property Color: TColor read GetColor;
  published
    property About: ThkAboutInfo read FAbout write SetAbout stored False;
    property Enabled: Boolean read GetEnabled write SetEnabled default True;
    property Interval: Cardinal read GetInterval write SetInterval default 100;
    property OnTimer: TNotifyEvent read FOnTimer write SetOnTimer;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Runner', [ThkColorPicker]);
end;

{ ThkColorPicker }

constructor ThkColorPicker.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FAbout := 'ThkColorPicker v1.0, Copyright (c) 2004 Hristo Kostov';
  FDC := GetDC(0);
  FTimer := TTimer.Create(Self);
  FTimer.Interval := 100;
end;

destructor ThkColorPicker.Destroy;
begin
  ReleaseDC(0, FDC);
  inherited Destroy;
end;

function ThkColorPicker.GetColor: TColor;
var
  P: TPoint;
begin
  GetCursorPos(P);
  Result := GetPixel(FDC, P.X, P.Y);
end;

function ThkColorPicker.GetEnabled: Boolean;
begin
  Result := FTimer.Enabled;
end;

function ThkColorPicker.GetInterval: Cardinal;
begin
  Result := FTimer.Interval;
end;

procedure ThkColorPicker.SetAbout(Value: ThkAboutInfo);
begin
  { do nothing }
end;

procedure ThkColorPicker.SetEnabled(Value: Boolean);
begin
  FTimer.Enabled := Value;
end;

procedure ThkColorPicker.SetInterval(Value: Cardinal);
begin
  FTimer.Interval := Value;
end;

procedure ThkColorPicker.SetOnTimer(Value: TNotifyEvent);
begin
  FOnTimer := Value;
  if Assigned(FOnTimer) then
    FTimer.OnTimer := TimerHandler
  else
    FTimer.OnTimer := nil;
end;

procedure ThkColorPicker.TimerHandler(Sender: TObject);
begin
  if Assigned(FOnTimer) then
    FOnTimer(Self);
end;

end.
